@@ -88,7 +88,6 @@ class QGraphViz_Core(QWidget):
         self.hovered_Edge = None
         self.hovered_Edge_id = None
         self.current_pos = [0,0]
-        self.current_path = ""
         self.mouse_down=False
         self.min_cursor_edge_dist=min_cursor_edge_dist
         self.show_subgraphs=show_subgraphs
@@ -234,13 +233,13 @@ class QGraphViz_Core(QWidget):
 
     def load_file(self, filename):
         self.engine.graph = self.parser.parseFile(filename)
-        self.current_path = filename
+        self.engine.current_path = filename
         self.build()
         self.update()
 
     def loadAJson(self, filename):
         self.engine.graph = self.parser.fromJSON(filename)
-        self.current_path = filename
+        self.engine.current_path = filename
         self.build()
         self.update()
         
@@ -252,11 +251,11 @@ class QGraphViz_Core(QWidget):
             self.hovered_Node = None
 
         self.parser.save(filename, self.engine.graph)
-        self.current_path=filename
+        self.engine.current_path=filename
 
     def saveAsJson(self, filename):
         self.parser.toJSON(filename, self.engine.graph)
-        self.current_path=filename
+        self.engine.current_path=filename
 
 
     # ================== Helper methods ==================
@@ -711,14 +710,14 @@ class QGraphViz_Core(QWidget):
                                 img_path = img_params[0]
                                 width =  int(img_params[1])
                                 height =  int(img_params[2])
-                                img_path2 = os.path.join(os.path.dirname(self.current_path),img_path)
+                                img_path2 = os.path.join(os.path.dirname(self.engine.current_path),img_path)
                                 if(os.path.isfile(img_path)):
                                     image = QImage(img_path)
                                 elif(os.path.isfile(img_path2)):
                                     image = QImage(img_path2)
                         else:
                             img_path = node.kwargs["shape"]
-                            img_path2 = os.path.join(os.path.dirname(self.current_path),img_path)
+                            img_path2 = os.path.join(os.path.dirname(self.engine.current_path),img_path)
                             if(os.path.isfile(img_path)):
                                 image = QImage(img_path)
                                 width =  image.size().width()
@@ -733,8 +732,8 @@ class QGraphViz_Core(QWidget):
                                     height=100
 
                         if image is not None:
-                            node.size[0] = width
-                            node.size[1] = height
+                            node.size[0] = width if width>node.size[0] else node.size[0]
+                            node.size[1] = height if height>node.size[1] else node.size[1]
                             painter.drawImage(
                                 QRect(
                                     gpos[0]-node.size[0]/2,
@@ -750,10 +749,22 @@ class QGraphViz_Core(QWidget):
 
 
                 if("label" in node.kwargs.keys()):
+                    txt = node.kwargs["label"].split("\n")
+                    width = 0
+                    height = 0
+                    for t in txt:
+                        if(t==""):
+                            t="A"
+                        rect = self.engine.fm.boundingRect(t)
+                        width=rect.width() if rect.width()>width else width
+                        height+=rect.height()
+
+                    width+=self.engine.margins[0]
+                    height+self.engine.margins[1]
                     painter.drawText(
-                        gpos[0]-node.size[0]/2,
-                        gpos[1]-node.size[1]/2,
-                        node.size[0], node.size[1],
+                        gpos[0]-width/2,
+                        gpos[1]-height/2,
+                        width, height,
                         Qt.AlignCenter|Qt.AlignTop,node.kwargs["label"])
             else:
                 if(self.show_subgraphs):
